@@ -3,6 +3,12 @@ from Table import *
 from Module import *
 from validations import *
 
+NOTE_SCRIPT_ALIAS  = 'Path to an executable that will be run with the CGI as parameter.'
+NOTE_CHANGE_USER   = 'Execute the CGI under its owner user ID.'
+NOTE_ERROR_HANDLER = 'Send errors exactly as they are generated.'
+NOTE_CHECK_FILE    = 'Check whether the file is in place.'
+NOTE_PASS_REQ      = 'Pass all the headers to the CGI as they were received by the web server.'
+
 class ModuleCgiBase (Module, FormHelper):
     PROPERTIES = [
         'script_alias',
@@ -17,14 +23,15 @@ class ModuleCgiBase (Module, FormHelper):
         Module.__init__ (self, name, cfg, prefix, submit_url)
 
     def _op_render (self):
-        txt   = ""
-        table = Table(2)
-        self.AddTableEntry    (table, "Script Alias",  "%s!script_alias" % (self._prefix))
-        self.AddTableEntry    (table, "Change to UID", "%s!change_user"  % (self._prefix))
-        self.AddTableCheckbox (table, "Error handler", "%s!error_handler"% (self._prefix), False)
-        self.AddTableCheckbox (table, "Check file",    "%s!check_file"   % (self._prefix), True)
-        self.AddTableCheckbox (table, "Pass Request",  "%s!pass_req_headers" % (self._prefix), False)
-        txt += str(table)
+        txt   = "<h2>Common CGI options</h2>"
+
+        table = TableProps()
+        self.AddPropEntry (table, "Script Alias",  "%s!script_alias" % (self._prefix), NOTE_SCRIPT_ALIAS)
+        self.AddPropEntry (table, "Change to UID", "%s!change_user"  % (self._prefix), NOTE_CHANGE_USER)
+        self.AddPropCheck (table, "Error handler", "%s!error_handler"% (self._prefix), False, NOTE_ERROR_HANDLER)
+        self.AddPropCheck (table, "Check file",    "%s!check_file"   % (self._prefix), True, NOTE_CHECK_FILE)
+        self.AddPropCheck (table, "Pass Request",  "%s!pass_req_headers" % (self._prefix), False, NOTE_PASS_REQ)
+        txt += self.Indent(table)
 
         return txt
 
