@@ -3,6 +3,7 @@ from Table import *
 from Module import *
 from validations import *
 from consts import *
+from ModuleBalancer import *
 
 class ModuleMirror (Module, FormHelper):
     PROPERTIES = [
@@ -16,9 +17,11 @@ class ModuleMirror (Module, FormHelper):
     def _op_render (self):
         prefix = "%s!balancer" % (self._prefix)
 
-        table = Table(2)
-        e = self.AddTableOptions_Reload (table, "Balancer", prefix, BALANCERS)
-        txt = str(table) + self.Indent(e)
+        table = TableProps()
+        e = self.AddPropOptions_Reload (table, "Balancer", prefix, BALANCERS, NOTE_BALANCER)
+
+        txt  = "<h2>Load balancing options</h2>"
+        txt += self.Indent (str(table) + e)
         return txt
 
     def _op_apply_changes (self, uri, post):
