@@ -8,6 +8,8 @@ from RuleList import *
 from Module import *
 from consts import *
 
+DEFAULT_RULE_WARNING = 'The default match ought not to be changed.'
+
 NOTE_DOCUMENT_ROOT = 'Allow to specify an alternative document root path.'
 NOTE_HANDLER       = 'How the connection will be handler.'
 NOTE_HTTPS_ONLY    = 'Enable to allow access to the resource only by https.'
@@ -15,10 +17,8 @@ NOTE_ALLOW_FROM    = 'List of IPs and subnets allowed to access the resource.'
 NOTE_VALIDATOR     = 'Which, if any, will be the authentication method.'
 
 DATA_VALIDATION = [
-    ("vserver!.*?!(directory|extensions|request)!.*?!document_root", 
-     (validations.is_local_dir_exists, 'cfg')),
-    ("vserver!.*?!(directory|extensions|request)!.*?!allow_from",
-     validations.is_ip_or_netmask_list)
+    ("vserver!.*?!rule!(\d+)!document_root", (validations.is_local_dir_exists, 'cfg')),
+    ("vserver!.*?!rule!(\d+)!allow_from",     validations.is_ip_or_netmask_list)
 ]
 
 class PageEntry (PageMenu, FormHelper):
@@ -147,6 +147,9 @@ class PageEntry (PageMenu, FormHelper):
     def _render_rule (self):
         pre = "%s!match"%(self._conf_prefix)
 
+        if self._cfg.get_val(pre) == 'default':
+            return self.Dialog (DEFAULT_RULE_WARNING, 'important-information')
+
         # Change the rule type
         table = TableProps()
         e = self.AddPropOptions_Reload (table, "Rule Type", pre, RULES, "")
