@@ -177,7 +177,7 @@ cherokee_buffer_add (cherokee_buffer_t *buf, const char *txt, size_t size)
 
 	/* Get memory
 	 */
-	if (free < (size+1)) {
+	if ((cuint_t) free < (size+1)) {
 		if (unlikely (realloc_inc_bufsize(buf, size - free)) != ret_ok)
 			return ret_nomem;
 	}
@@ -203,10 +203,10 @@ cherokee_buffer_add_buffer (cherokee_buffer_t *buf, cherokee_buffer_t *buf2)
 ret_t
 cherokee_buffer_add_long10 (cherokee_buffer_t *buf, clong_t lNum)
 {
-	culong_t ulNum = (culong_t) lNum;
-	cuint_t  flgNeg = 0;
-	int      newlen = 0;
-	size_t   i = (IOS_NUMBUF - 1);
+	culong_t ulNum                 = (culong_t) lNum;
+	cuint_t  flgNeg                = 0;
+	int      newlen                = 0;
+	size_t   i                     = (IOS_NUMBUF - 1);
 	char     szOutBuf[IOS_NUMBUF];
 
 	if (lNum < 0L) {
@@ -231,7 +231,7 @@ cherokee_buffer_add_long10 (cherokee_buffer_t *buf, clong_t lNum)
 	/* Verify free space in buffer and if needed then enlarge it.
 	*/
 	newlen = buf->len + (int) ((IOS_NUMBUF - 1) - i);
-	if (unlikely (newlen >= buf->size)) {
+	if (unlikely ((cuint_t)newlen >= buf->size)) {
 		if (unlikely (realloc_new_bufsize(buf, newlen)) != ret_ok)
 			return ret_nomem;
 	}
@@ -241,7 +241,6 @@ cherokee_buffer_add_long10 (cherokee_buffer_t *buf, clong_t lNum)
 	strcpy (buf->buf + buf->len, &szOutBuf[i]);
 
 	buf->len = newlen;
-
 	return ret_ok;
 }
 
@@ -249,11 +248,11 @@ cherokee_buffer_add_long10 (cherokee_buffer_t *buf, clong_t lNum)
 ret_t
 cherokee_buffer_add_llong10 (cherokee_buffer_t *buf, cllong_t lNum)
 {
-	cullong_t ulNum = (cullong_t) lNum;
-	cuint_t  flgNeg = 0;
-	int      newlen = 0;
-	size_t   i = (IOS_NUMBUF - 1);
-	char     szOutBuf[IOS_NUMBUF];
+	cullong_t ulNum                 = (cullong_t) lNum;
+	cuint_t   flgNeg                = 0;
+	int       newlen                = 0;
+	size_t    i                     = (IOS_NUMBUF - 1);
+	char      szOutBuf[IOS_NUMBUF];
 
 	if (lNum < 0L) {
 		flgNeg = 1;
@@ -277,7 +276,7 @@ cherokee_buffer_add_llong10 (cherokee_buffer_t *buf, cllong_t lNum)
 	/* Verify free space in buffer and if needed then enlarge it.
 	*/
 	newlen = buf->len + (int) ((IOS_NUMBUF - 1) - i);
-	if (unlikely (newlen >= buf->size)) {
+	if (unlikely ((cuint_t)newlen >= buf->size)) {
 		if (unlikely (realloc_new_bufsize(buf, newlen)) != ret_ok)
 			return ret_nomem;
 	}
@@ -295,8 +294,8 @@ cherokee_buffer_add_llong10 (cherokee_buffer_t *buf, cllong_t lNum)
 ret_t
 cherokee_buffer_add_ulong10 (cherokee_buffer_t *buf, culong_t ulNum)
 {
-	int     newlen = 0;
-	size_t  i = (IOS_NUMBUF - 1);
+	int     newlen               = 0;
+	size_t  i                    = (IOS_NUMBUF - 1);
 	char    szOutBuf[IOS_NUMBUF];
 
 	szOutBuf[i] = '\0';
@@ -311,7 +310,7 @@ cherokee_buffer_add_ulong10 (cherokee_buffer_t *buf, culong_t ulNum)
 	/* Verify free space in buffer and if needed then enlarge it.
 	*/
 	newlen = buf->len + (int) ((IOS_NUMBUF - 1) - i);
-	if (unlikely (newlen >= buf->size)) {
+	if (unlikely ((cuint_t)newlen >= buf->size)) {
 		if (unlikely (realloc_new_bufsize(buf, newlen)) != ret_ok)
 			return ret_nomem;
 	}
@@ -329,8 +328,8 @@ cherokee_buffer_add_ulong10 (cherokee_buffer_t *buf, culong_t ulNum)
 ret_t
 cherokee_buffer_add_ullong10 (cherokee_buffer_t *buf, cullong_t ulNum)
 {
-	int     newlen = 0;
-	size_t  i = (IOS_NUMBUF - 1);
+	int     newlen               = 0;
+	size_t  i                    = (IOS_NUMBUF - 1);
 	char    szOutBuf[IOS_NUMBUF];
 
 	szOutBuf[i] = '\0';
@@ -345,7 +344,7 @@ cherokee_buffer_add_ullong10 (cherokee_buffer_t *buf, cullong_t ulNum)
 	/* Verify free space in buffer and if needed then enlarge it.
 	*/
 	newlen = buf->len + (int) ((IOS_NUMBUF - 1) - i);
-	if (unlikely (newlen >= buf->size)) {
+	if (unlikely ((cuint_t)newlen >= buf->size)) {
 		if (unlikely (realloc_new_bufsize(buf, newlen)) != ret_ok)
 			return ret_nomem;
 	}
@@ -366,9 +365,9 @@ cherokee_buffer_add_ullong10 (cherokee_buffer_t *buf, cullong_t ulNum)
 ret_t
 cherokee_buffer_add_ulong16 (cherokee_buffer_t *buf, culong_t ulNum)
 {
-	size_t  i = (IOS_NUMBUF - 1);
-	int     ival = 0;
-	int     newlen = 0;
+	size_t  i                     = (IOS_NUMBUF - 1);
+	int     ival                  = 0;
+	int     newlen                = 0;
 	char    szOutBuf[IOS_NUMBUF];
 
 	szOutBuf[i] = '\0';
@@ -384,7 +383,7 @@ cherokee_buffer_add_ulong16 (cherokee_buffer_t *buf, culong_t ulNum)
 	/* Verify free space in buffer and if needed then enlarge it.
 	*/
 	newlen = buf->len + (int) ((IOS_NUMBUF - 1) - i);
-	if (unlikely (newlen >= buf->size)) {
+	if (unlikely ((cuint_t)newlen >= buf->size)) {
 		if (unlikely (realloc_new_bufsize(buf, newlen)) != ret_ok)
 			return ret_nomem;
 	}
@@ -405,9 +404,9 @@ cherokee_buffer_add_ulong16 (cherokee_buffer_t *buf, culong_t ulNum)
 ret_t
 cherokee_buffer_add_ullong16 (cherokee_buffer_t *buf, cullong_t ulNum)
 {
-	size_t  i = (IOS_NUMBUF - 1);
-	int     ival = 0;
-	int     newlen = 0;
+	size_t  i                     = (IOS_NUMBUF - 1);
+	int     ival                  = 0;
+	int     newlen                = 0;
 	char    szOutBuf[IOS_NUMBUF];
 
 	szOutBuf[i] = '\0';
@@ -423,7 +422,7 @@ cherokee_buffer_add_ullong16 (cherokee_buffer_t *buf, cullong_t ulNum)
 	/* Verify free space in buffer and if needed then enlarge it.
 	*/
 	newlen = buf->len + (int) ((IOS_NUMBUF - 1) - i);
-	if (unlikely (newlen >= buf->size)) {
+	if (unlikely ((cuint_t)newlen >= buf->size)) {
 		if (unlikely (realloc_new_bufsize(buf, newlen)) != ret_ok)
 			return ret_nomem;
 	}
@@ -439,18 +438,32 @@ cherokee_buffer_add_ullong16 (cherokee_buffer_t *buf, cullong_t ulNum)
 
 
 ret_t 
-cherokee_buffer_add_va_fixed (cherokee_buffer_t  *buf, char *format, ...)
+cherokee_buffer_add_va_fixed (cherokee_buffer_t *buf, char *format, ...)
 {
-	cuint_t len;
+	int len;
+	int size = buf->size - buf->len;	/* final '\0' is always available */
 	va_list ap;
 
+	/* Test for minimum buffer size.
+	 */
+	if (size < 1)
+		return ret_error;
+
+	/* Format the string into the buffer.
+	 * NOTE: len does NOT include '\0', size includes '\0' (len + 1)
+	 */
 	va_start (ap, format);
-	len = vsnprintf (buf->buf + buf->len, buf->size - buf->len - 1, format, ap);
+	len = vsnprintf (buf->buf + buf->len, size, format, ap);
 	va_end (ap);
 
 	if (unlikely (len < 0)) 
 		return ret_error;
 
+	/* Don't expand buffer if there is not enough space.
+	 */
+	if (unlikely ( len >= size )) 
+		return ret_error;
+
 	buf->len += len;
 	return ret_ok;
 }
@@ -459,26 +472,65 @@ cherokee_buffer_add_va_fixed (cherokee_buffer_t  *buf, char *format, ...)
 ret_t 
 cherokee_buffer_add_va_list (cherokee_buffer_t *buf, char *format, va_list args)
 {
-	cuint_t len;
-	cuint_t estimated_length;
+	int len;
+	int estimation;
+	int size;
+	ret_t ret;
 	va_list args2;
 
 	va_copy (args2, args);
 
-	estimated_length = cherokee_estimate_va_length (format, args);
-	cherokee_buffer_ensure_size (buf, buf->len + estimated_length + 2);
+	/* Estimate resulting formatted string length.
+	 */
+	estimation = cherokee_estimate_va_length (format, args);
+	if (unlikely (estimation) < 0) {
+		PRINT_ERROR ("  -> '%s', esti=%d ( < 0)\n", format, estimation);
+		return ret_error;
+	}
+
+	/* Ensure enough size for buffer.
+	 */
+	ret = cherokee_buffer_ensure_size (buf, buf->len + estimation + 2);
+	if (ret != ret_ok) {
+		PRINT_ERROR ("  -> '%s', esti=%d ensure_size=%d failed !\n", format, estimation, buf->len + estimation + 2);
+		return ret;
+	}
+
+	/* Format the string into the buffer.
+	 * NOTE: len does NOT include '\0', size includes '\0' (len + 1)
+	 */
+	size = buf->size - buf->len;
+	if (size < 1) {
+		PRINT_ERROR ("  -> '%s', esti=%d size=%d ( < 1)!\n", format, estimation, size);
+		return ret_error;
+	}
+	len = vsnprintf (buf->buf + buf->len, size, format, args2);
 
-	len = vsnprintf (buf->buf + buf->len, buf->size - buf->len - 1, format, args2);
-	
 #if 0
-	if (estimated_length < len)
-		PRINT_ERROR ("  -> '%s' -> '%s', esti=%d real=%d\n", 
-			     format, buf->buf + buf->len, estimated_length, len);
+	if (estimation < len)
+		PRINT_ERROR ("  -> '%s' -> '%s', esti=%d real=%d size=%d\n", 
+			     format, buf->buf + buf->len, estimation, len, size);
 #endif
 
-	if (unlikely (len < 0)) 
+	if (unlikely (len < 0))
 		return ret_error;
 
+	/* At this point buf-size is always greater than buf-len, thus size > 0.
+	 */
+	if (len >= size) {
+		TRACE(ENTRIES, "Failed estimation=%d, needed=%d available size=%d\n", estimation, len, size);
+
+		cherokee_buffer_ensure_size (buf, buf->len + len + 2);
+		size = buf->size - buf->len;
+		len = vsnprintf (buf->buf + buf->len, size, format, args2);
+
+		if (unlikely (len < 0)) 
+			return ret_error;
+
+		if (unlikely (len >= size)) 
+			return ret_error;
+	}
+
 	buf->len += len;
 	return ret_ok;
 }
@@ -547,13 +599,13 @@ cherokee_buffer_add_char_n (cherokee_buffer_t *buf, char c, int num)
 
 
 ret_t
-cherokee_buffer_prepend (cherokee_buffer_t  *buf, char *txt, size_t size)
+cherokee_buffer_prepend (cherokee_buffer_t *buf, char *txt, size_t size)
 {
 	int free = buf->size - buf->len;
 
 	/* Get memory
 	 */
-	if (free < (size+1)) {
+	if ((cuint_t) free < (size+1)) {
 		if (unlikely (realloc_inc_bufsize(buf, size - free)) != ret_ok)
 			return ret_nomem;
 	}
@@ -579,11 +631,8 @@ cherokee_buffer_is_endding (cherokee_buffer_t *buf, char c)
 
 
 ret_t
-cherokee_buffer_move_to_begin (cherokee_buffer_t *buf, int pos)
+cherokee_buffer_move_to_begin (cherokee_buffer_t *buf, cuint_t pos)
 {
-	if (pos <= 0) 
-		return ret_ok;
-
 	if (pos >= buf->len) {
 		cherokee_buffer_clean(buf);
 		return ret_ok;
@@ -653,11 +702,11 @@ cherokee_buffer_ensure_size (cherokee_buffer_t *buf, size_t size)
 
 
 ret_t 
-cherokee_buffer_drop_endding (cherokee_buffer_t *buffer, int num_chars)
+cherokee_buffer_drop_endding (cherokee_buffer_t *buffer, cuint_t num_chars)
 {
 	int num;
 
-	if ((buffer->buf == NULL) || (num_chars <= 0)) {
+	if (buffer->buf == NULL) {
 		return ret_ok;
 	}
 
@@ -673,13 +722,13 @@ cherokee_buffer_drop_endding (cherokee_buffer_t *buffer, int num_chars)
 ret_t
 cherokee_buffer_swap_chars (cherokee_buffer_t *buffer, char a, char b)
 {
-	int i = 0;
+	cuint_t i;
 
 	if (buffer->buf == NULL) {
 		return ret_ok;
 	}
 
-	for (i=0; i<buffer->len; i++) {
+	for (i=0; i < buffer->len; i++) {
 		if (buffer->buf[i] == a) {
 			buffer->buf[i] = b;
 		}
@@ -795,7 +844,7 @@ cherokee_buffer_case_cmp (cherokee_buffer_t *buf, char *txt, cuint_t txt_len)
 
 
 size_t
-cherokee_buffer_cnt_spn (cherokee_buffer_t *buf, int offset, char *str) 
+cherokee_buffer_cnt_spn (cherokee_buffer_t *buf, cuint_t offset, char *str) 
 {
 	if (unlikely ((buf->buf == NULL) || (buf->len <= offset)))
 		return 0;
@@ -805,7 +854,7 @@ cherokee_buffer_cnt_spn (cherokee_buffer_t *buf, int offset, char *str)
 
 
 size_t 
-cherokee_buffer_cnt_cspn (cherokee_buffer_t *buf, int offset, char *str) 
+cherokee_buffer_cnt_cspn (cherokee_buffer_t *buf, cuint_t offset, char *str) 
 {
 	if (unlikely ((buf->buf == NULL) || (buf->len <= offset)))
 		return 0;
@@ -815,7 +864,7 @@ cherokee_buffer_cnt_cspn (cherokee_buffer_t *buf, int offset, char *str)
 
 
 crc_t 
-cherokee_buffer_crc32 (cherokee_buffer_t  *buf)
+cherokee_buffer_crc32 (cherokee_buffer_t *buf)
 {
 	return crc32_sz (buf->buf, buf->len);
 }
@@ -945,7 +994,7 @@ cherokee_buffer_print_debug (cherokee_buffer_t *buf, int len)
 	char          *hex_text   = NULL;
 	char          *ascii_text = NULL;
 
-	if ((len == -1) || (buf->len <= len)) {
+	if ((len == -1) || (buf->len <= (cuint_t)len)) {
 		length = buf->len;
 	} else {
 		length = len;
@@ -1024,6 +1073,12 @@ cherokee_buffer_unescape_uri (cherokee_buffer_t *buffer)
 	if (unlikely (buffer->buf == NULL))
 		return ret_error;
 
+	/* Verify string termination,
+	 * we assume there are no '\0' inside buffer.
+	 */
+	if (buffer->buf[buffer->len] != '\0')
+		buffer->buf[buffer->len]  = '\0';
+
 	/* Verify if unescaping is needed.
 	 */
 	if ((psrc = strchr (buffer->buf, '%')) == NULL)
@@ -1064,13 +1119,17 @@ cherokee_buffer_unescape_uri (cherokee_buffer_t *buffer)
 
 
 ret_t 
-cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t *src)
+cherokee_buffer_add_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t *src)
 {
 	ret_t   ret;
-	cuint_t i;
-	cuint_t j;
-	cuint_t extra = 0;
-	char   *p0, *p;
+	size_t  len0 = 0;
+	size_t  extra = 0;
+	char   *p0, *p1, *p2;
+
+	/* Verify that source string is not empty.
+	 */
+	if (unlikely (src->buf == NULL))
+		return ret_error;
 
 	/* Verify string termination,
 	 * we assume there are no '\0' inside buffer.
@@ -1080,21 +1139,24 @@ cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t *src)
 
 	/* Verify if string has to be escaped.
 	 */
-	if ((p0 = strpbrk (src->buf, "<>&\"")) == NULL)
-		return ret_not_found;
+	if ((p0 = strpbrk (src->buf, "<>&\"")) == NULL) {
+		/* No escape found, simply add src to buf.
+		 */
+		return cherokee_buffer_add_buffer (buf, src);
+	}
 
 	/* Count extra characters
 	 */
-	for (p = p0; *p != '\0'; ++p) {
-		switch(*p) {
-			case '<':
-			case '>':
+	for (p1 = p0; *p1 != '\0'; ++p1) {
+		switch(*p1) {
+			case '<':	/* &lt; */
+			case '>':	/* &gt; */
 				extra += 3;
 				continue;
-			case '&':
+			case '&':	/* &amp; */
 				extra += 4;
 				continue;
-			case '"':
+			case '"':	/* &quot; */
 				extra += 5;
 				continue;
 			default:
@@ -1104,67 +1166,78 @@ cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t *src)
 
 	/* Verify there are no embedded '\0'.
 	 */
-	if ( ((int) (p - src->buf)) != src->len)
+	if ( (cuint_t)(p1 - src->buf) != src->len)
 		return ret_error;
 
-	/* Copy the buffer
+	/* Ensure there is proper buffer size.
 	 */
-	cherokee_buffer_clean (buf);
+	ret = cherokee_buffer_ensure_addlen (buf, src->len + extra + 1);
+	if (ret != ret_ok)
+		return ret;
 
-	ret = cherokee_buffer_ensure_size (buf, src->len + extra + 1);
-	if (ret != ret_ok) return ret;
-	
-	ret = cherokee_buffer_add_buffer (buf, src);
-	if (ret != ret_ok) return ret;
-
-	/* Make the changes
+	/* Escape and copy data to destination buffer.
 	 */
-	for (i = 0, j = 0; i < buf->len; i++) {
-		char c = buf->buf[i+j]; 
-
-		switch (c) {
-		case '<':
-			memmove (&buf->buf[i+j+4], &buf->buf[i+j+1], buf->len-i);
-			memcpy (&buf->buf[i+j], "&lt;", 4);
-			j += 3;
-			break;
-
-		case '>':
-			memmove (&buf->buf[i+j+4], &buf->buf[i+j+1], buf->len-i);
-			memcpy (&buf->buf[i+j], "&gt;", 4);
-			j += 3;
-			break;
-
-		case '&':
-			memmove (&buf->buf[i+j+5], &buf->buf[i+j+1], buf->len-i);
-			memcpy (&buf->buf[i+j], "&amp;", 5);
-			j += 4;
-			break;
-
-		case '"':
-			memmove (&buf->buf[i+j+6], &buf->buf[i+j+1], buf->len-i);
-			memcpy (&buf->buf[i+j], "&quot;", 6);
-			j += 5;
-			break;
-		}
+	if (p0 != src->buf) {
+		len0 = (size_t) (p0 - src->buf);
+		memcpy (&buf->buf[buf->len], src->buf, len0);
 	}
 
+	p2 = &buf->buf[buf->len + len0];
+
+	for (p1 = p0; *p1 != '\0'; ++p1) {
+		switch (*p1) {
+		case '<':
+			memcpy (p2, "&lt;", 4);
+			p2 += 4;
+			continue;
+
+		case '>':
+			memcpy (p2, "&gt;", 4);
+			p2 += 4;
+			continue;
+
+		case '&':
+			memcpy (p2, "&amp;", 5);
+			p2 += 5;
+			continue;
+
+		case '"':
+			memcpy (p2, "&quot;", 6);
+			p2 += 6;
+			continue;
+
+		default:
+			*p2++ = *p1;
+			continue;
+		}
+	}
+	
 	/* Set the new length
 	 */
-	buf->len += extra;
+	buf->len += src->len + extra;
+	buf->buf[buf->len] = '\0';
 
 	return ret_ok;
 }
 
 
+ret_t 
+cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t *src)
+{
+	cherokee_buffer_clean (buf);
+	return cherokee_buffer_add_escape_html (buf, src);
+}
+
+
 ret_t 
 cherokee_buffer_decode_base64 (cherokee_buffer_t *buf)
 {
-	char space[128];
-	int  space_idx = 0;
-	int  i, phase  = 0;
-	int  d, prev_d = 0;
-	int  buf_pos   = 0;
+	cuint_t  i;
+	char     space[128];
+	int      space_idx = 0;
+	int      phase     = 0;
+	int      d, prev_d = 0;
+	int      buf_pos   = 0;
 
 	/* Base-64 decoding: This represents binary data as printable
 	 * ASCII characters. Three 8-bit binary bytes are turned into
@@ -1246,7 +1319,7 @@ cherokee_buffer_encode_base64 (cherokee_buffer_t *buf, cherokee_buffer_t *encode
 	cuchar_t         *in;
 	cuchar_t         *out;
 	ret_t             ret;
-	int               i, j;
+	cuint_t           i, j;
 	cuint_t           inlen   = buf->len;
 
 	static const char base64tab[]=
@@ -1280,8 +1353,10 @@ cherokee_buffer_encode_base64 (cherokee_buffer_t *buf, cherokee_buffer_t *encode
 		f = base64tab [((b & 15) << 2) | (c >> 6)];
 		g = base64tab [c & 63 ];
 
-		if (i + 1 >= inlen) f='=';
-		if (i + 2 >= inlen) g='=';
+		if (i + 1 >= inlen)
+			f = '=';
+		if (i + 2 >= inlen)
+			g = '=';
 
 		out[j++] = d;
 		out[j++] = e;
@@ -1440,7 +1515,7 @@ cherokee_buffer_encode_hex (cherokee_buffer_t *buf, cherokee_buffer_t *encoded)
 ret_t 
 cherokee_buffer_decode_hex (cherokee_buffer_t *buf)
 {
-	int i;
+	cuint_t i;
 
 	static char hex_to_bin [128] = {
 		-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,    /*            */
@@ -1456,8 +1531,8 @@ cherokee_buffer_decode_hex (cherokee_buffer_t *buf)
 	for (i=0; i<buf->len/2; i++) {
 		/* It uses << 1 rather than * 2
 		 */
-		cuint_t  b1 = buf->buf[(i << 1)] & 127;
-		cuint_t  b2 = buf->buf[(i << 1) + 1] & 127;
+		cint_t b1 = buf->buf[(i << 1)] & 127;
+		cint_t b2 = buf->buf[(i << 1) + 1] & 127;
 
  		b1 = hex_to_bin[b1];
  		b2 = hex_to_bin[b2];
@@ -1528,7 +1603,7 @@ cherokee_buffer_replace_string (cherokee_buffer_t *buf,
 	/* Verify formal parameters
 	 * (those which are not tested would raise a segment violation).
 	 */
-	if (buf->buf == NULL ||
+	if (buf == NULL || buf->buf == NULL ||
 	    substring == NULL || substring_length < 1 ||
 		replacement == NULL || replacement_length < 0)
 		return ret_deny;
@@ -1693,7 +1768,7 @@ cherokee_buffer_substitute_string (cherokee_buffer_t *bufsrc,
 
 
 ret_t 
-cherokee_buffer_add_comma_marks (cherokee_buffer_t  *buf)
+cherokee_buffer_add_comma_marks (cherokee_buffer_t *buf)
 {
 	cuint_t  off, num, i;
 	char    *p;
