@@ -246,7 +246,20 @@ cherokee_config_node_read (cherokee_config_node_t *conf, const char *key, cherok
 
 
 ret_t 
-cherokee_config_node_read_int  (cherokee_config_node_t *conf, const char *key, int *num)
+cherokee_config_node_copy (cherokee_config_node_t *conf, const char *key, cherokee_buffer_t *buf)
+{
+	ret_t              ret;
+	cherokee_buffer_t *tmp = NULL;
+	
+	ret = cherokee_config_node_read (conf, key, &tmp);
+	if (ret != ret_ok) return ret;
+
+	return cherokee_buffer_add_buffer (buf, tmp);
+}
+
+
+ret_t 
+cherokee_config_node_read_int (cherokee_config_node_t *conf, const char *key, int *num)
 {
 	ret_t                   ret;
 	cherokee_config_node_t *tmp;
@@ -259,6 +272,20 @@ cherokee_config_node_read_int  (cherokee_config_node_t *conf, const char *key, i
 }
 
 
+ret_t 
+cherokee_config_node_read_bool (cherokee_config_node_t *conf, const char *key, cherokee_boolean_t *val)
+{
+	ret_t ret;
+	int   tmp;
+
+	ret = cherokee_config_node_read_int (conf, key, &tmp);
+	if (ret != ret_ok) return ret;
+
+	*val = !! tmp;
+	return ret_ok;
+}
+
+
 ret_t 
 cherokee_config_node_read_path (cherokee_config_node_t *conf, const char *key, cherokee_buffer_t **buf)
 {
