@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -25,19 +25,20 @@
 #ifndef CHEROKEE_ENCODE_GZIP_H
 #define CHEROKEE_ENCODE_GZIP_H
 
-#include <common-internal.h>
+#include <common.h>
 
 #include "zlib/zlib.h"
 #include "module.h"
 #include "encoder.h"
 
-
+/* Data types
+ */
 typedef struct {
 	cherokee_encoder_t  base;
+
 	z_stream            stream;
 	void               *workspace;
 	cherokee_boolean_t  add_header;
-
 	uLong               crc32;
 	uLong               size;
 } cherokee_encoder_gzip_t;
@@ -45,8 +46,13 @@ typedef struct {
 #define ENC_GZIP(x) ((cherokee_encoder_gzip_t *)(x))
 
 
+/* Methods
+ */
+ret_t cherokee_encoder_gzip_configure   (cherokee_config_node_t *conf, cherokee_server_t *srv, cherokee_module_props_t **props);
+
 ret_t cherokee_encoder_gzip_new         (cherokee_encoder_gzip_t **encoder);
 ret_t cherokee_encoder_gzip_free        (cherokee_encoder_gzip_t  *encoder);
+
 ret_t cherokee_encoder_gzip_add_headers (cherokee_encoder_gzip_t  *encoder, cherokee_buffer_t *buf);
 ret_t cherokee_encoder_gzip_init        (cherokee_encoder_gzip_t  *encoder);
 ret_t cherokee_encoder_gzip_encode      (cherokee_encoder_gzip_t  *encoder, cherokee_buffer_t *in, cherokee_buffer_t *out);
