@@ -85,6 +85,7 @@ _add (cherokee_fdpoll_select_t *fdp, int fd, int rw)
 	/* Check the fd limit
 	 */
 	if (cherokee_fdpoll_is_full(FDPOLL(fdp))) {
+		PRINT_ERROR_S("win32_add: fdpoll is full !\n");
 		return ret_error;
 	}
 
@@ -222,7 +223,7 @@ _reset (cherokee_fdpoll_select_t *fdp, int fd)
 
 
 ret_t
-fdpoll_win32_get_fdlimits (int *system_fd_limit, int *fd_limit)
+fdpoll_win32_get_fdlimits (cuint_t *system_fd_limit, cuint_t *fd_limit)
 {
 	*system_fd_limit = 0;
 	*fd_limit = FD_SETSIZE;
