@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -32,11 +32,11 @@
 
 
 ret_t
-cherokee_handler_init_base (cherokee_handler_t *hdl, void *conn)
+cherokee_handler_init_base (cherokee_handler_t *hdl, void *conn, cherokee_handler_props_t *props, cherokee_plugin_info_handler_t *info)
 {
 	/* Init the base class
 	 */
-	cherokee_module_init_base (MODULE(hdl));
+	cherokee_module_init_base (MODULE(hdl), MODULE_PROPS(props), PLUGIN_INFO(info));
 
 	/* Pure virtual methods
 	 */
@@ -45,26 +45,18 @@ cherokee_handler_init_base (cherokee_handler_t *hdl, void *conn)
 
 	/* Parent reference
 	 */
-	hdl->connection = conn;
+	hdl->connection    = conn;
+
 	return ret_ok;
 }
 
 
-ret_t 
-cherokee_handler_free_base (cherokee_handler_t *hdl)
-{
-	free (hdl);
-	return ret_ok;
-}
-
-
-/* 	Virtual method hidding layer
+/* Virtual method hidding layer
  */
+
 ret_t
 cherokee_handler_free (cherokee_handler_t *hdl)
 {
-	ret_t ret;
-
 	/* Sanity check
 	 */
 	return_if_fail (hdl != NULL, ret_error);
@@ -72,12 +64,9 @@ cherokee_handler_free (cherokee_handler_t *hdl)
 	if (MODULE(hdl)->free == NULL) {
 		return ret_error;
 	}
-
-	/* Call the destructor virtual method
-	 */
-	ret = MODULE(hdl)->free (hdl); 
-	if (unlikely(ret < ret_ok)) return ret;
 	
+	MODULE(hdl)->free (hdl); 
+
 	/* Free the handler memory
 	 */
 	free (hdl);
@@ -135,3 +124,20 @@ cherokee_handler_step (cherokee_handler_t *hdl, cherokee_buffer_t *buffer)
 
 
 
+/* Handler properties methods
+ */
+
+ret_t 
+cherokee_handler_props_init_base (cherokee_handler_props_t *props, module_func_props_free_t free_func)
+{
+	props->valid_methods = http_unknown;
+
+	return cherokee_module_props_init_base (MODULE_PROPS(props), free_func);
+}
+
+
+ret_t 
+cherokee_handler_props_free_base (cherokee_handler_props_t *props)
+{
+	return cherokee_module_props_free_base (MODULE_PROPS(props));
+}
