@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -27,13 +27,26 @@
 
 #include "common-internal.h"
 
-#include "handler.h"
-#include "module_loader.h"
+#include "handler_file.h"
+#include "handler_dirlist.h"
+
+
+typedef struct {
+	cherokee_module_props_t           base;
+	cherokee_boolean_t                allow_pathinfo;
+	cherokee_handler_file_props_t    *props_file;
+	cherokee_handler_dirlist_props_t *props_dirlist;
+} cherokee_handler_common_props_t;
+
+#define PROP_COMMON(x)  ((cherokee_handler_common_props_t *)(x))
 
 
 /* Library init function
  */
-void  common_init                 (cherokee_module_loader_t *loader);
-ret_t cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties);
+void  PLUGIN_INIT_NAME(common)           (cherokee_plugin_loader_t *loader);
+
+ret_t cherokee_handler_common_configure  (cherokee_config_node_t *conf, cherokee_server_t *srv, cherokee_module_props_t **props);
+ret_t cherokee_handler_common_new        (cherokee_handler_t **hdl, void *cnt, cherokee_module_props_t *props);
+ret_t cherokee_handler_common_props_free (cherokee_handler_common_props_t *props);
 
 #endif /* CHEROKEE_HANDLER_COMMON_H */
