@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -29,8 +29,9 @@
 
 #include "handler.h"
 #include "buffer.h"
-#include "module_loader.h"
+#include "plugin_loader.h"
 #include "socket.h"
+#include "balancer.h"
 #include "handler_cgi_base.h"
 #include "fcgi_manager.h"
 #include "fcgi_dispatcher.h"
@@ -54,43 +55,54 @@ typedef enum {
 } cherokee_handler_fastcgi_post_t;
 
 
+/* Data structure
+ */
 typedef struct {
-	cherokee_handler_cgi_base_t base;
-
-	list_t                         *fastcgi_env_ref;
-	list_t                         *server_list;	
+	cherokee_handler_cgi_base_t     base;
 
 	cuint_t                         id;
-	cuchar_t                        generation;
-	
-	cuint_t                         nsockets;
-	cuint_t                         nkeepalive;
-	cuint_t                         npipeline;
-
+	cuchar_t                        generation;	
 	cherokee_buffer_t               write_buffer;	
+	off_t                           post_len;
 
 	cherokee_fcgi_manager_t        *manager;
 	cherokee_fcgi_dispatcher_t     *dispatcher;
 
 	cherokee_handler_fastcgi_init_t init_phase;
 	cherokee_handler_fastcgi_post_t post_phase;
-	size_t                          post_len;
-
 } cherokee_handler_fastcgi_t;
 
-#define HANDLER_FASTCGI(x)  ((cherokee_handler_fastcgi_t *)(x))
+#define HDL_FASTCGI(x)       ((cherokee_handler_fastcgi_t *)(x))
+
+
+/* Properties data structure
+ */
+typedef struct {
+	cherokee_handler_cgi_base_t     base;
+
+	cherokee_balancer_t            *balancer;
+	cherokee_list_t                 fastcgi_env_ref;
+
+	cuint_t                         nsockets;
+	cuint_t                         nkeepalive;
+	cuint_t                         npipeline;
+} cherokee_handler_fastcgi_props_t;
+
+#define PROP_FASTCGI(x)          ((cherokee_handler_fastcgi_props_t *)(x))
+#define HANDLER_FASTCGI_PROPS(x) (PROP_FASTCGI(MODULE(x)->props))
 
  
 /* Library init function
  */
-void  MODULE_INIT(fastcgi) (cherokee_module_loader_t *loader);
+void  PLUGIN_INIT_NAME(fastcgi)            (cherokee_plugin_loader_t *loader);
 
 /* Methods
  */
-ret_t cherokee_handler_fastcgi_new         (cherokee_handler_t        **hdl, void *cnt, cherokee_table_t *properties);
+ret_t cherokee_handler_fastcgi_new         (cherokee_handler_t        **hdl, void *cnt, cherokee_module_props_t *properties);
 ret_t cherokee_handler_fastcgi_free        (cherokee_handler_fastcgi_t *hdl);
 ret_t cherokee_handler_fastcgi_init        (cherokee_handler_fastcgi_t *hdl);
 ret_t cherokee_handler_fastcgi_add_headers (cherokee_handler_fastcgi_t *hdl, cherokee_buffer_t *buffer);
 ret_t cherokee_handler_fastcgi_step        (cherokee_handler_fastcgi_t *hdl, cherokee_buffer_t *buffer);
 
+
 #endif /* CHEROKEE_HANDLER_CGI_H */
