@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -29,11 +29,10 @@
 
 #include "handler.h"
 #include "buffer.h"
-#include "module_loader.h"
+#include "plugin_loader.h"
 #include "socket.h"
 #include "handler_cgi_base.h"
-#include "ext_source.h"
-
+#include "balancer.h"
 
 typedef enum {
 	fcgi_post_unknown,
@@ -42,26 +41,34 @@ typedef enum {
 	fcgi_post_write
 } cherokee_handler_fcgi_post_t;
 
+/* Data structure
+ */
 typedef struct {
 	cherokee_handler_cgi_base_t   base;
 	cherokee_socket_t             socket;
-	cherokee_ext_source_t        *src;
 	cherokee_handler_fcgi_post_t  post_phase;
-	list_t                       *server_list;
-	cuint_t                       post_len;
+	off_t                         post_len;
 	cherokee_buffer_t             write_buffer;
 } cherokee_handler_fcgi_t;
 
-#define HANDLER_FCGI(x)  ((cherokee_handler_fcgi_t *)(x))
+#define HDL_FCGI(x)  ((cherokee_handler_fcgi_t *)(x))
 
- 
-/* Library init function
- */
-void  MODULE_INIT(fcgi) (cherokee_module_loader_t *loader);
 
-/* Methods
+/* Properties
  */
-ret_t cherokee_handler_fcgi_new  (cherokee_handler_t     **hdl, void *cnt, cherokee_table_t *properties);
+typedef struct {
+	cherokee_handler_cgi_base_t  base;
+	cherokee_list_t              server_list; 	
+	cherokee_balancer_t         *balancer;
+} cherokee_handler_fcgi_props_t;
+
+#define PROP_FCGI(x)          ((cherokee_handler_fcgi_props_t *)(x))
+#define HANDLER_FCGI_PROPS(x) (PROP_FCGI (MODULE(x)->props))
+
+
+ /* Methods
+ */
+ret_t cherokee_handler_fcgi_new  (cherokee_handler_t     **hdl, void *cnt, cherokee_module_props_t *props);
 ret_t cherokee_handler_fcgi_free (cherokee_handler_fcgi_t *hdl);
 ret_t cherokee_handler_fcgi_init (cherokee_handler_fcgi_t *hdl);
 
