@@ -118,6 +118,8 @@ cherokee_handler_server_info_configure (cherokee_config_node_t *conf, cherokee_s
 	cherokee_list_t                      *i;
 	cherokee_handler_server_info_props_t *props;
 
+	UNUSED(srv);
+
 	if (*_props == NULL) {
 		CHEROKEE_NEW_STRUCT (n, handler_server_info_props);
 
@@ -288,10 +290,13 @@ build_modules_table_content_while (cherokee_buffer_t *key, void *value, void *pa
 	int *validators = (int *) params[5];
 	int *generic    = (int *) params[6];
 	int *balancer   = (int *) params[7];
+	int *rules      = (int *) params[8];
 
 	cherokee_plugin_loader_entry_t *entry = value;
 	cherokee_plugin_info_t         *mod   = entry->info;
 
+	UNUSED(key);
+
 	if (mod->type & cherokee_logger) {
 		*loggers += 1;
 	} else if (mod->type & cherokee_handler) {
@@ -304,6 +309,8 @@ build_modules_table_content_while (cherokee_buffer_t *key, void *value, void *pa
 		*generic += 1;
 	} else if (mod->type & cherokee_balancer) {
 		*balancer += 1;
+	} else if (mod->type & cherokee_rule) {
+		*rules += 1;
 	} else {
 		PRINT_ERROR("Unknown module type (%d)\n", mod->type);
 	}
@@ -320,7 +327,8 @@ build_modules_table_content (cherokee_buffer_t *buf, cherokee_server_t *srv)
 	cuint_t  validators = 0;	   
 	cuint_t  generic    = 0;
 	cuint_t  balancers  = 0;
-	void    *params[]   = {buf, srv, &loggers, &handlers, &encoders, &validators, &generic, &balancers};
+	cuint_t  rules      = 0;
+	void    *params[]   = {buf, srv, &loggers, &handlers, &encoders, &validators, &generic, &balancers, &rules};
 
 	cherokee_avl_while (&srv->loader.table, 
 			    (cherokee_avl_while_func_t) build_modules_table_content_while, 
