@@ -42,7 +42,8 @@ typedef enum {
 	cherokee_handler   = 1 << 2,
 	cherokee_encoder   = 1 << 3,
 	cherokee_validator = 1 << 4,
-	cherokee_balancer  = 1 << 5
+	cherokee_balancer  = 1 << 5,
+	cherokee_rule      = 1 << 6
 } cherokee_plugin_type_t;
 
 
@@ -131,7 +132,7 @@ typedef struct {
 	void                                                        \
 	PLUGIN_INIT_NAME(name) (cherokee_plugin_loader_t *loader)   \
 	{                                                           \
-		;                                                   \
+		UNUSED(loader);					    \
 	}                                                           \
 								    \
 
