@@ -101,7 +101,7 @@ configure (cherokee_rule_directory_t *rule,
 
 	ret = cherokee_config_node_copy (conf, "directory", &rule->directory);
 	if (ret != ret_ok) {
-		PRINT_ERROR ("Rule prio=%d needs a 'directory' property", 
+		PRINT_ERROR ("Rule prio=%d needs a 'directory' property\n", 
 			     RULE(rule)->priority);
 		return ret_error;
 	}
