@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -28,18 +28,24 @@
 #include "validator.h"
 #include "connection.h"
 
+typedef struct {
+	cherokee_module_props_t base;
+	cherokee_buffer_t       password_file;
+} cherokee_validator_htdigest_props_t;
+
 typedef struct {
 	   cherokee_validator_t  validator;
-	   char                 *file_ref;
 } cherokee_validator_htdigest_t;
 
-#define HTDIGEST(x) ((cherokee_validator_htdigest_t *)(x))
+#define HTDIGEST(x)          ((cherokee_validator_htdigest_t *)(x))
+#define PROP_HTDIGEST(p)     ((cherokee_validator_htdigest_props_t *)(p))
+#define VAL_HTDIGEST_PROP(x) (PROP_HTDIGEST (MODULE(x)->props))
 
 
-ret_t cherokee_validator_htdigest_new  (cherokee_validator_htdigest_t **htdigest, cherokee_table_t *properties);
-ret_t cherokee_validator_htdigest_free (cherokee_validator_htdigest_t  *htdigest);
+ret_t cherokee_validator_htdigest_new         (cherokee_validator_htdigest_t **htdigest, cherokee_module_props_t *props);
+ret_t cherokee_validator_htdigest_free        (cherokee_validator_htdigest_t  *htdigest);
 
-ret_t cherokee_validator_htdigest_check       (cherokee_validator_htdigest_t *htdigest, cherokee_connection_t *conn);
-ret_t cherokee_validator_htdigest_add_headers (cherokee_validator_htdigest_t *htdigest, cherokee_connection_t *conn, cherokee_buffer_t *buf);
+ret_t cherokee_validator_htdigest_check       (cherokee_validator_htdigest_t  *htdigest, cherokee_connection_t *conn);
+ret_t cherokee_validator_htdigest_add_headers (cherokee_validator_htdigest_t  *htdigest, cherokee_connection_t *conn, cherokee_buffer_t *buf);
 
 #endif /* CHEROKEE_VALIDATOR_HTDIGEST_H */
