@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -28,17 +28,22 @@
 #include "validator.h"
 #include "connection.h"
 
+typedef struct {
+	cherokee_module_props_t  base;
+	cherokee_buffer_t        password_file;
+} cherokee_validator_plain_props_t;
 
 typedef struct {
-	   cherokee_validator_t  validator;
-	   const char           *file_ref;
+	cherokee_validator_t  validator;
 } cherokee_validator_plain_t;
 
-#define PLAIN(x) ((cherokee_validator_plain_t *)(x))
+#define PLAIN(x)          ((cherokee_validator_plain_t *)(x))
+#define PROP_PLAIN(p)     ((cherokee_validator_plain_props_t *)(p))
+#define VAL_PLAIN_PROP(x) (PROP_PLAIN (MODULE(x)->props))
 
 
-ret_t cherokee_validator_plain_new  (cherokee_validator_plain_t **plain, cherokee_table_t *properties);
-ret_t cherokee_validator_plain_free (cherokee_validator_plain_t  *plain);
+ret_t cherokee_validator_plain_new         (cherokee_validator_plain_t **plain, cherokee_module_props_t *props);
+ret_t cherokee_validator_plain_free        (cherokee_validator_plain_t  *plain);
 
 ret_t cherokee_validator_plain_check       (cherokee_validator_plain_t  *plain, cherokee_connection_t *conn);
 ret_t cherokee_validator_plain_add_headers (cherokee_validator_plain_t  *plain, cherokee_connection_t *conn, cherokee_buffer_t *buf);
