@@ -2,8 +2,9 @@ from base import *
 
 MAGIC = "This is the magic string"
 CONF = """
-vserver!default!directory!/cgi-bin1!handler = cgi
-vserver!default!directory!/cgi-bin1!priority = 150
+vserver!default!rule!150!match = directory
+vserver!default!rule!150!match!directory = /cgi-bin1
+vserver!default!rule!150!handler = cgi
 """
 
 class Test (TestBase):
