@@ -1,13 +1,18 @@
 from base import *
 
+CONF = """
+vserver!default!rule!180!match = directory
+vserver!default!rule!180!match!directory = /cgi-bin4
+vserver!default!rule!180!handler = cgi
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
         self.name = "CGI with pathinfo III"
 
         self.request          = "GET /cgi-bin4/inside/test/test_parameter HTTP/1.0\r\n"
-        self.conf             = "Directory /cgi-bin4 { Handler cgi }"
-
+        self.conf             = CONF
         self.expected_error   = 200
         self.expected_content = "PathInfo is /test_parameter"
 
