@@ -1,6 +1,13 @@
 from base import *
 
-MAGIC = "Virtual Host test magic string"
+MAGIC = "First virtual Host test magic string"
+
+CONF = """
+vserver!cherokee.test!document_root = %s
+vserver!cherokee.test!domain!1 = cherokee.test
+vserver!cherokee.test!rule!1!match = default
+vserver!cherokee.test!rule!1!handler = common
+"""
 
 class Test (TestBase):
     def __init__ (self):
@@ -14,11 +21,7 @@ class Test (TestBase):
         self.expected_content = MAGIC
 
     def Prepare (self, www):
-        dir = self.Mkdir (www, "vhost1")
-        self.WriteFile (www, "vhost1/file", 0444, MAGIC)
+        d = self.Mkdir (www, "vhost1")
+        self.WriteFile (d, "file", 0444, MAGIC)
         
-        self.conf = """Server cherokee.test {
-                         DocumentRoot %s
-                         Directory / { Handler common }
-                    }""" % (dir)
-
+        self.conf = CONF % (d)
