@@ -7,5 +7,5 @@ class Test (TestBase):
 
         self.expected_error = 200
         self.request        = "GET / HTTP/1.1\r\n" +\
-                              "Host: www.0x50.org:80\r\n"
+                              "Host: www.cherokee-project.com:80\r\n"
 
