@@ -1,11 +1,18 @@
 from base import *
 
+CONF = """
+vserver!default!rule!350!match = directory
+vserver!default!rule!350!match!directory = /php1
+vserver!default!rule!350!handler = phpcgi
+vserver!default!rule!350!handler!interpreter = %s
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
         self.name             = "PHP simple, phpcgi"
         self.request          = "GET /php1/simple.php HTTP/1.0\r\n"
-        self.conf             = "Directory /php1 { Handler phpcgi }"
+        self.conf             = CONF % (look_for_php())
         self.expected_error   = 200
         self.expected_content = "This is PHP"
 
@@ -15,4 +22,4 @@ class Test (TestBase):
                         "<?php echo 'This'.' is '.'PHP' ?>")
 
     def Precondition (self):
-        return os.path.exists (PHPCGI_PATH)
+        return os.path.exists (look_for_php())
