@@ -2,6 +2,13 @@ from base import *
 
 MAGIC = "This_is_the_magic_key"
 
+CONF = """
+vserver!default!rule!360!match = directory
+vserver!default!rule!360!match!directory = /dr_common
+vserver!default!rule!360!handler = common
+vserver!default!rule!360!document_root = %s
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -11,12 +18,8 @@ class Test (TestBase):
         self.expected_content = MAGIC
         
     def Prepare (self, www):
-        dir = self.Mkdir (www, "dr_common_another/dir")
-        self.WriteFile (www, "dr_common_another/dir/test_index.html", 0444, MAGIC)
+        d = self.Mkdir (www, "dr_common_another/dir")
+        self.WriteFile (d, "test_index.html", 0444, MAGIC)
+
+        self.conf = CONF % (d)
 
-        self.conf             = """
-           Directory /dr_common {
-             Handler common
-             DocumentRoot %s
-           }
-           """ % (dir)
