@@ -15,4 +15,4 @@ class Test (TestBase):
         self.WriteFile (www, "php4/get.php", 0444, '<?php echo $_GET["magic"] ?>')
 
     def Precondition (self):
-        return os.path.exists (PHPCGI_PATH)
+        return os.path.exists (look_for_php())
