@@ -4,8 +4,9 @@ MAGIC = "Sesamo"
 CONTENT = "This is the content of " + MAGIC
 
 CONF = """
-vserver!default!directory!/nn1!handler = nn
-vserver!default!directory!/nn1!priority = 480
+vserver!default!rule!480!match = directory
+vserver!default!rule!480!match!directory = /nn1
+vserver!default!rule!480!handler = nn
 """
 
 class Test (TestBase):
