@@ -5,6 +5,16 @@ from base import *
 USER="cherokeeqa"
 PASS="cherokeeqa"
 
+CONF = """
+vserver!default!rule!610!match = directory
+vserver!default!rule!610!match!directory = /privpam
+vserver!default!rule!610!match!final = 0
+vserver!default!rule!610!auth = pam
+vserver!default!rule!610!auth!methods = basic
+vserver!default!rule!610!auth!realm = Test PAM
+"""
+
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -23,13 +33,7 @@ class Test (TestBase):
             return
 
         directory = self.Mkdir (www, "privpam")
-        self.conf = """Directory /privpam {
-                         Handler common
-                             Auth Basic {
-                             Name "Test PAM"
-                             Method pam
-                         }
-                    }"""
+        self.conf = CONF
 
     def Precondition (self):
         # It will only work it the server runs as root
