@@ -5,6 +5,15 @@ from base import *
 USER="cherokeeqa"
 PASS="invalid"
 
+CONF = """
+vserver!default!rule!620!match = directory
+vserver!default!rule!620!match!directory = /privpam2
+vserver!default!rule!620!match!final = 0
+vserver!default!rule!620!auth = pam
+vserver!default!rule!620!auth!methods = basic
+vserver!default!rule!620!auth!realm = Test PAM
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -23,13 +32,7 @@ class Test (TestBase):
             return
 
         directory = self.Mkdir (www, "privpam2")
-        self.conf = """Directory /privpam2 {
-                         Handler common
-                         Auth Basic {
-                           Name "Test PAM"
-                           Method pam
-                         }
-                       }"""
+        self.conf = CONF
 
     def Precondition (self):
         # It will only work it the server runs as root
