@@ -2,6 +2,14 @@ from base import *
 
 MAGIC="This is the magic string for the DocumentRoot test - common"
 
+CONF = """
+vserver!default!rule!630!match = directory
+vserver!default!rule!630!match!directory = /droot
+vserver!default!rule!630!handler = common
+vserver!default!rule!630!document_root = %s
+"""
+
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -11,11 +19,8 @@ class Test (TestBase):
         self.expected_content = MAGIC
 
     def Prepare (self, www):
-        self.Mkdir     (www, "documentroot/subdir/subdir")
-        self.WriteFile (www, "documentroot/subdir/subdir/file", 0444, MAGIC)
+        d = self.Mkdir (www, "documentroot/subdir/subdir")
+        self.WriteFile (d, "file", 0444, MAGIC)
 
-        self.conf = """Directory /droot {
-                          Handler common
-                          DocumentRoot %s/documentroot/subdir/subdir
-                    }""" % (www)
+        self.conf = CONF % (d)
 
