@@ -1,6 +1,15 @@
 import os
 from base import *
 
+CONF = """
+vserver!directoryindex3!document_root = %s
+vserver!directoryindex3!domain!1 = directoryindex3
+vserver!directoryindex3!directory_index = index.php,/super_test_index.php
+vserver!directoryindex3!rule!1!match = default
+vserver!directoryindex3!rule!1!handler = common
+"""
+
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -18,13 +27,10 @@ class Test (TestBase):
                                   "ScriptName /super_test_index.php",
                                   "RequestUri /inside/"]
 
-        self.conf              = """
-        Server directoryindex3 {
-           Directory / { Handler common }
-           DirectoryIndex index.php, /super_test_index.php
-           DocumentRoot %s
-           %s
-        }""" % (self.dr, self.php_conf)
+        self.conf = CONF % (self.dr)
+
+        for php in self.php_conf.split("\n"):
+            self.conf += "vserver!directoryindex3!rule!%s\n" % (php)
 
     def JustBefore (self, www):
         self.WriteFile (self.dr, "super_test_index.php", 0666, """<?php
@@ -34,7 +40,7 @@ class Test (TestBase):
                         ?>""")
 
     def Precondition (self):
-        if not os.path.exists (PHPCGI_PATH):
+        if not os.path.exists (look_for_php()):
             return False
 
         f = os.popen("ps -p %d -L | wc -l" % (os.getpid()))
