@@ -13,7 +13,9 @@ CONF = """
 # 
 #    cgi.fix_pathinfo=0
 #
-vserver!default!directory!/pathinfo!handler = common
+vserver!default!rule!670!match = directory
+vserver!default!rule!670!match!directory = /pathinfo
+vserver!default!rule!670!handler = common
 """
 
 class Test (TestBase):
