@@ -3,14 +3,17 @@ from base import *
 MAGIC = "It shouldn't inherit in this case"
 
 CONF = """
-vserver!default!directory!/inherit2/dir1/dir2/dir3!auth = plain
-vserver!default!directory!/inherit2/dir1/dir2/dir3!auth!methods = basic
-vserver!default!directory!/inherit2/dir1/dir2/dir3!auth!realm = Test
-vserver!default!directory!/inherit2/dir1/dir2/dir3!auth!passwdfile = %s
-vserver!default!directory!/inherit2/dir1/dir2/dir3!priority = 710
+vserver!default!rule!710!match = directory
+vserver!default!rule!710!match!directory = /inherit2/dir1/dir2/dir3
+vserver!default!rule!710!auth = plain
+vserver!default!rule!710!auth!methods = basic
+vserver!default!rule!710!auth!realm = Test
+vserver!default!rule!710!auth!passwdfile = %s
 
-vserver!default!directory!/inherit2!handler = file
-vserver!default!directory!/inherit2!priority = 711
+vserver!default!rule!711!match = directory
+vserver!default!rule!711!match!directory = /inherit2
+vserver!default!rule!711!match!final = 0
+vserver!default!rule!711!handler = file
 """
 
 class Test (TestBase):
