@@ -2,6 +2,14 @@ from base import *
 
 MAGIC = "Allow From test"
 
+CONF = """
+vserver!default!rule!730!match = directory
+vserver!default!rule!730!match!directory = /allow1
+vserver!default!rule!730!match!final = 0
+vserver!default!rule!730!allow_from = 99.99.99.99
+"""
+
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -9,7 +17,8 @@ class Test (TestBase):
         self.request           = "GET /allow1/file HTTP/1.0\r\n"
         self.expected_error    = 403
         self.forbidden_content = MAGIC
-        self.conf              = """
+        self.conf              = CONF
+        a = """
               Directory /allow1/ {
                  Handler file
                  Allow from 99.99.99.99
