@@ -2,6 +2,13 @@ from base import *
 
 MAGIC = "Allow From test 2"
 
+CONF = """
+vserver!default!rule!740!match = directory
+vserver!default!rule!740!match!directory = /allow2
+vserver!default!rule!740!match!final = 0
+vserver!default!rule!740!allow_from = 127.0.0.1,::1
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -9,12 +16,7 @@ class Test (TestBase):
         self.request           = "GET /allow2/file HTTP/1.0\r\n"
         self.expected_error    = 200
         self.expected_content  = MAGIC
-        self.conf              = """
-              Directory /allow2/ {
-                 Handler file
-                 Allow from 127.0.0.1, ::1
-              }
-              """
+        self.conf              = CONF
 
     def Prepare (self, www):
         self.Mkdir (www, "allow2")
