@@ -3,6 +3,13 @@ from os import system
 
 MAGIC = "Allow From range 2"
 
+CONF = """
+vserver!default!rule!760!match = directory
+vserver!default!rule!760!match!directory = /allow_range2
+vserver!default!rule!760!match!final = 0
+vserver!default!rule!760!allow_from = 127.0.0.1/8
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -10,12 +17,7 @@ class Test (TestBase):
         self.request           = "GET /allow_range2/file HTTP/1.0\r\n"
         self.expected_error    = 200
         self.expected_content  = MAGIC
-        self.conf              = """
-              Directory /allow_range2/ {
-                 Handler file
-                 Allow from 127.0.0.1/8
-              }
-              """
+        self.conf              = CONF
 
     def Prepare (self, www):
         self.Mkdir (www, "allow_range2")
