@@ -3,6 +3,17 @@ from base import *
 REQUIRED  = "This is working, yeahhh"
 FORBIDDEN = "It shouldn't appear in the text"
 
+CONF = """
+vserver!default!rule!790!match = directory
+vserver!default!rule!790!match!directory = /extension1
+vserver!default!rule!790!handler = file
+
+vserver!default!rule!791!match = extensions
+vserver!default!rule!791!match!extensions = xyz
+vserver!default!rule!791!handler = phpcgi
+vserver!default!rule!791!handler!interpreter = %s
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -11,17 +22,7 @@ class Test (TestBase):
         self.expected_error    = 200
         self.expected_content  = REQUIRED
         self.forbidden_content = FORBIDDEN
-        self.conf              = """
-              Directory /extension1 {
-                 Handler file
-              }
-
-              Extension xyz {
-                 Handler phpcgi {
-                   Interpreter %s
-                 }
-              }
-              """ % (PHPCGI_PATH)
+        self.conf              = CONF % (look_for_php())
 
     def Prepare (self, www):
         self.Mkdir (www, "extension1")
@@ -29,6 +30,6 @@ class Test (TestBase):
                         '<?php /* %s */ echo "%s"; ?>' % (FORBIDDEN, REQUIRED))
 
     def Precondition (self):
-        return os.path.exists (PHPCGI_PATH)
+        return os.path.exists (look_for_php())
 
 
