@@ -4,12 +4,14 @@ REQUIRED  = "This is working! :-)"
 FORBIDDEN = "It shouldn't appear in the text"
 
 CONF = """
-vserver!default!directory!/extension2!handler = file
-vserver!default!directory!/extension2!priority = 800
+vserver!default!rule!800!match = directory
+vserver!default!rule!800!match!directory = /extension2
+vserver!default!rule!800!handler = file
 
-vserver!default!extensions!abc,def,ghi!handler = phpcgi
-vserver!default!extensions!abc,def,ghi!handler!interpreter = %s
-vserver!default!extensions!abc,def,ghi!priority = 801
+vserver!default!rule!801!match = extensions
+vserver!default!rule!801!match!extensions = abc,def,ghi
+vserver!default!rule!801!handler = phpcgi
+vserver!default!rule!801!handler!interpreter = %s
 """
 
 class Test (TestBase):
