@@ -4,9 +4,10 @@ MAGIC1 = "First part"
 MAGIC2 = "Second part"
 
 CONF = """
-vserver!default!directory!/dr_common_index!handler = common
-vserver!default!directory!/dr_common_index!document_root = %s
-vserver!default!directory!/dr_common_index!priority = 810
+vserver!default!rule!810!match = directory
+vserver!default!rule!810!match!directory = /dr_common_index
+vserver!default!rule!810!handler = common
+vserver!default!rule!810!document_root = %s
 """
 
 class Test (TestBase):
