@@ -7,10 +7,11 @@ ENV1_VALUE = "Value1"
 ENV2_VALUE = "This is the second one"
 
 CONF = """
-vserver!default!directory!/cgienvs!handler = cgi
-vserver!default!directory!/cgienvs!handler!env!%s = %s
-vserver!default!directory!/cgienvs!handler!env!%s = %s
-vserver!default!directory!/cgienvs!priority = 880
+vserver!default!rule!880!match = directory
+vserver!default!rule!880!match!directory = /cgienvs
+vserver!default!rule!880!handler = cgi
+vserver!default!rule!880!handler!env!%s = %s
+vserver!default!rule!880!handler!env!%s = %s
 """
 
 class Test (TestBase):
@@ -20,13 +21,6 @@ class Test (TestBase):
 
         self.request           = "GET /cgienvs/cgi.cgi HTTP/1.0\r\n"
         self.conf              = CONF % (ENV1_NAME, ENV1_VALUE, ENV2_NAME, ENV2_VALUE)
-
-        self.conf2              = """Directory /cgienvs/ {
-                                    Handler cgi {
-                                      Env %s "%s"
-                                      Env %s "%s"
-                                    }
-                                 }""" % (ENV1_NAME, ENV1_VALUE, ENV2_NAME, ENV2_VALUE)
         self.expected_error    = 200
         self.expected_content  = ["Env1 %s = %s" % (ENV1_NAME, ENV1_VALUE), 
 						    "Env2 %s = %s" % (ENV2_NAME, ENV2_VALUE)]
