@@ -6,13 +6,19 @@ DIRS    = ["dir1", "dir2", "dir3", "dir4"]
 LINKS   = {"link1": "dir1", "link2": "file1" }
 BLINKS  = {"broken2": "del1", "broken1": "del2"}
 
+CONF = """
+vserver!default!rule!930!match = directory
+vserver!default!rule!930!match!directory = /brokenlinks1
+vserver!default!rule!930!handler = dirlist
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
         self.name = "Broken links"
 
         self.request           = "GET /brokenlinks1/ HTTP/1.0\r\n"
-        self.conf              = "Directory /brokenlinks1 { Handler dirlist }"
+        self.conf              = CONF
         self.expected_error    = 200
         self.expected_content  = FILES + DIRS + LINKS.keys()
 
