@@ -9,6 +9,15 @@ USER          = "username"
 PASSWD        = "alo"
 PASSWD_APACHE = "$apr1$VVusx/..$B6P.9/IK81S3M1QNVdfdX0"
 
+CONF = """
+vserver!default!rule!950!match = directory
+vserver!default!rule!950!match!directory = /apachemd5_1
+vserver!default!rule!950!match!final = 0
+vserver!default!rule!950!auth = htpasswd
+vserver!default!rule!950!auth!methods = basic
+vserver!default!rule!950!auth!realm = %s
+vserver!default!rule!950!auth!passwdfile = %s
+"""
 
 class Test (TestBase):
     def __init__ (self):
@@ -26,11 +35,4 @@ class Test (TestBase):
         tdir  = self.Mkdir (www, "apachemd5_1")
         passf = self.WriteFile (tdir, "passwd", 0444, '%s:%s\n' %(USER, PASSWD_APACHE))
         self.WriteFile (tdir, "file", 0444, MAGIC)
-
-        self.conf             = """Directory /apachemd5_1 {
-                                     Handler file
-                                     Auth Basic {
-                                          Name "%s"
-                                          Method htpasswd { PasswdFile %s }
-                                     }
-                                }""" % (REALM, passf)
+        self.conf = CONF % (REALM, passf)
