@@ -9,6 +9,15 @@ USER         = "username"
 PASSWD       = "alo"
 PASSWD_CRYPT = "kA7oFNEzu4SrI"
 
+CONF = """
+vserver!default!rule!980!match = directory
+vserver!default!rule!980!match!directory = /htpasswd_crypt
+vserver!default!rule!980!match!final = 0
+vserver!default!rule!980!auth = htpasswd
+vserver!default!rule!980!auth!methods = basic
+vserver!default!rule!980!auth!realm = %s
+vserver!default!rule!980!auth!passwdfile = %s
+"""
 
 class Test (TestBase):
     def __init__ (self):
@@ -27,10 +36,4 @@ class Test (TestBase):
         passf = self.WriteFile (tdir, "passwd", 0444, '%s:%s\n' %(USER, PASSWD_CRYPT))
         self.WriteFile (tdir, "file", 0444, MAGIC)
 
-        self.conf             = """Directory /htpasswd_crypt {
-                                     Handler file
-                                     Auth Basic {
-                                          Name "%s"
-                                          Method htpasswd { PasswdFile %s }
-                                     }
-                                }""" % (REALM, passf)
+        self.conf = CONF % (REALM, passf)
