@@ -7,6 +7,16 @@ USER   = "username"
 PASSWD = "itissecret"
 DIR    = "digest_htdigest1"
 
+CONF = """
+vserver!default!rule!1000!match = directory
+vserver!default!rule!1000!match!directory = %s
+vserver!default!rule!1000!match!final = 0
+vserver!default!rule!1000!auth = htdigest
+vserver!default!rule!1000!auth!methods = digest
+vserver!default!rule!1000!auth!realm = %s
+vserver!default!rule!1000!auth!passwdfile = %s
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -57,13 +67,4 @@ class Test (TestBase):
 
         # Set the configuration
         #
-        self.conf             = """
-           Directory /%s {
-               Handler file
-               Auth Digest {
-                  Name "%s"
-                  Method htdigest {
-                    PasswdFile %s
-                  }
-               }
-           }""" % (DIR, REALM, passfile)
+        self.conf = CONF % ('/%s'%(DIR), REALM, passfile)
