@@ -22,5 +22,5 @@ class Test (TestBase):
         self.WriteFile (www, "Post1Mb.php", 0444, "<?php echo $_POST['var']; ?>")
 
     def Precondition (self):
-        return os.path.exists (PHPCGI_PATH)
+        return os.path.exists (look_for_php())
 
