@@ -2,13 +2,19 @@ from base import *
 
 PARAMS = "param1=one&param2=two&param3"
 
+CONF = """
+vserver!default!rule!1020!match = directory
+vserver!default!rule!1020!match!directory = /querystring
+vserver!default!rule!1020!handler = cgi
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
         self.name = "CGI: QUERY_STRING"
 
         self.request          = "GET /querystring/exec.cgi?%s HTTP/1.0\r\n" % (PARAMS)
-        self.conf             = "Directory /querystring { Handler cgi }"
+        self.conf             = CONF
         self.expected_error   = 200
         self.expected_content = "QUERY_STRING = %s" % (PARAMS)
 
