@@ -3,6 +3,13 @@ from base import *
 
 PATH_INFO   = "/this_is_the/path_info"
 
+CONF = """
+vserver!default!rule!1040!match = directory
+vserver!default!rule!1040!match!directory = /alias_and_pathinfo
+vserver!default!rule!1040!handler = cgi
+vserver!default!rule!1040!handler!script_alias = %s
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -22,9 +29,4 @@ class Test (TestBase):
                             echo "PATH_INFO = -${PATH_INFO}-"
                             """) 
 
-        self.conf             = """
-           Directory /alias_and_pathinfo {
-              Handler cgi {
-                ScriptAlias %s
-              }
-           }""" % (f)
+        self.conf = CONF % (f)
