@@ -35,12 +35,18 @@ DOCUMENTATION = """
    return the entire entity using a 200 (OK) response.
 """
 
+CONF = """
+vserver!default!rule!1050!match = directory
+vserver!default!rule!1050!match!directory = /if_range1
+vserver!default!rule!1050!handler = file
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
         self.name = "If-Range header, 200 error"
 
-        self.conf             = "Directory /if_range1 { Handler file }"
+        self.conf             = CONF
         self.expected_error   = 200
         self.expected_content = DOCUMENTATION
 
