@@ -4,11 +4,13 @@ COMMENT = "This is comment inside the CGI"
 TEXT    = "It should be printed by the CGI"
 
 CONF = """
-vserver!default!directory!/request_entry1!handler = file
-vserver!default!directory!/request_entry1!priority = 1100
+vserver!default!rule!1100!match = directory
+vserver!default!rule!1100!match!directory = /request_entry1
+vserver!default!rule!1100!handler = file
 
-vserver!default!request!request_entry1.*cgi$!handler = cgi
-vserver!default!request!request_entry1.*cgi$!priority = 1101
+vserver!default!rule!1101!match = request
+vserver!default!rule!1101!match!request = request_entry1.*cgi$
+vserver!default!rule!1101!handler = cgi
 """
 
 class Test (TestBase):
