@@ -6,6 +6,13 @@ HEADER_CONTENT = """
 ============================================
 """
 
+CONF = """
+vserver!default!rule!1140!match = directory
+vserver!default!rule!1140!match!directory = /header_file2
+vserver!default!rule!1140!handler = dirlist
+vserver!default!rule!1140!handler!notice_files = noexits1.txt,header.txt,noexits2.txt
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -15,12 +22,7 @@ class Test (TestBase):
         self.expected_error    = 200        
         self.expected_content  = [HEADER_CONTENT, "file1", "file2", "file3"]
         self.forbidden_content = ["header.txt"]
-
-        self.conf              = """Directory /header_file2 {
-                                       Handler dirlist {
-                                          HeaderFile noexits1.txt, header.txt, noexits2.txt
-                                       }
-                                  }"""
+        self.conf              = CONF
 
     def Prepare (self, www):
         d = self.Mkdir (www, "header_file2")
