@@ -2,6 +2,13 @@ from base import *
 
 TEST_FILE = "Cherokee is the fastest one"
 
+CONF = """        
+vserver!default!rule!1230!match = directory
+vserver!default!rule!1230!match!directory = /implicit_redir1
+vserver!default!rule!1230!handler = dirlist
+vserver!default!rule!1230!document_root = %s
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
@@ -15,7 +22,4 @@ class Test (TestBase):
         d  = self.Mkdir (www, "implicit_redir1_DIR")
         self.WriteFile (d, TEST_FILE, 0444, "");
 
-        self.conf              = """Directory /implicit_redir1 {
-                                      DocumentRoot %s
-                                      Handler dirlist
-                                    }""" % (d)
+        self.conf = CONF % (d)
