@@ -6,6 +6,15 @@ REALM  = "realm"
 USER   = "username"
 PASSWD = ""
 
+CONF = """
+vserver!default!rule!1300!match = directory
+vserver!default!rule!1300!match!directory = /digest_empty
+vserver!default!rule!1300!match!final = 0
+vserver!default!rule!1300!auth = plain
+vserver!default!rule!1300!auth!methods = digest
+vserver!default!rule!1300!auth!realm = %s
+vserver!default!rule!1300!auth!passwdfile = %s
+"""
 
 class Test (TestBase):
     def __init__ (self):
@@ -48,13 +57,4 @@ class Test (TestBase):
 
         # Set the configuration
         #
-        self.conf             = """
-           Directory /digest_empty {
-               Handler file
-               Auth Digest {
-                  Name "%s"
-                  Method plain {
-                    PasswdFile %s
-                  }
-               }
-           }""" % (REALM, passfile)
+        self.conf = CONF % (REALM, passfile)
