@@ -6,10 +6,11 @@ USER = "nobody"
 UID  = pwd.getpwnam(USER)[2]
 
 CONF = """
-vserver!default!directory!/change_user1!handler = phpcgi
-vserver!default!directory!/change_user1!handler!change_user = 1
-vserver!default!directory!/change_user1!handler!interpreter = %s
-vserver!default!directory!/change_user1!priority = 1310
+vserver!default!rule!1310!match = directory
+vserver!default!rule!1310!match!directory = /change_user1
+vserver!default!rule!1310!handler = phpcgi
+vserver!default!rule!1310!handler!change_user = 1
+vserver!default!rule!1310!handler!interpreter = %s
 """
 
 class Test (TestBase):
