@@ -21,4 +21,4 @@ class Test (TestBase):
         ?>""" % (HEADER_VAL))
 
     def Precondition (self):
-        return os.path.exists (PHPCGI_PATH)
+        return os.path.exists (look_for_php())
