@@ -64,4 +64,4 @@ class Test (TestBase):
         ?>""")
 
     def Precondition (self):
-        return os.path.exists (PHPCGI_PATH)
+        return os.path.exists (look_for_php())
