@@ -25,13 +25,14 @@ SCGIServer(TestHandler, port=%d).serve_forever()
 """ % (PORT)
 
 CONF = """
-vserver!default!directory!<dir>!handler = scgi
-vserver!default!directory!<dir>!handler!pass_req_headers = 1
-vserver!default!directory!<dir>!handler!balancer = round_robin
-vserver!default!directory!<dir>!handler!balancer!type = interpreter
-vserver!default!directory!<dir>!handler!balancer!local_scgi4!host = localhost:%d
-vserver!default!directory!<dir>!handler!balancer!local_scgi4!interpreter = %s %s
-vserver!default!directory!<dir>!priority = 1420
+vserver!default!rule!1420!match = directory
+vserver!default!rule!1420!match!directory = <dir>
+vserver!default!rule!1420!handler = scgi
+vserver!default!rule!1420!handler!pass_req_headers = 1
+vserver!default!rule!1420!handler!balancer = round_robin
+vserver!default!rule!1420!handler!balancer!type = interpreter
+vserver!default!rule!1420!handler!balancer!local_scgi4!host = localhost:%d
+vserver!default!rule!1420!handler!balancer!local_scgi4!interpreter = %s %s
 """
 
 class Test (TestBase):
