@@ -8,8 +8,10 @@ OFFSET = 15
 DIR    = "range_end_100k_noio"
 
 CONF = """
-vserver!default!directory!<dir>!handler = file
-vserver!default!directory!<dir>!handler!iocache = 0
+vserver!default!rule!1460!match = directory
+vserver!default!rule!1460!match!directory = <dir>
+vserver!default!rule!1460!handler = file
+vserver!default!rule!1460!handler!iocache = 0
 """
 
 class Test (TestBase):
