@@ -5,15 +5,16 @@ DIR  = "dir_redirect154/a/b/c"
 REQ  = "%s/d/e" % (DIR)
 
 CONF = """
-vserver!default!directory!/<dir>!handler = common
-vserver!default!directory!/<dir>!document_root = %s
-vserver!default!directory!/<dir>!priority = 1540
+vserver!default!rule!1540!match = directory
+vserver!default!rule!1540!match!directory = /<dir>
+vserver!default!rule!1540!handler = common
+vserver!default!rule!1540!document_root = %s
 """
 
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
-        self.name              = "common -> dirlist: redir to add final /"
+        self.name              = "common-dirlist: redir to add final /"
         self.request           = "GET /%s HTTP/1.0\r\n" % (REQ)
         self.expected_error    = 301
         self.expected_content  = "Location: /%s/" % (REQ)
